@@ -241,7 +241,7 @@ OUTPUT:
 
         Args:
             api_token (str): The API token for authentication.
-            base_url (str): The base URL of the Lastmile API. Default is 'https://lastmileai.dev/api'.
+            base_url (str): The base URL of the Lastmile API. Default is 'https://lastmileai.dev'.
             project_id (str): The project or application ID for the LastMile project to log to.
             logger (logging.Logger): An optional logger object. If not provided, a default logger is created.
             timeout (Optional[float]): Default timeout (seconds) for client API requests. Can be overridden in individual method calls.
@@ -1288,6 +1288,7 @@ OUTPUT:
         metadata: Optional[Dict[str, Any]] = None,
         experiment_id: Optional[str] = None,
         output_file_path: Optional[str] = None,
+        max_result_download_attempts: int = 3,
         timeout: Optional[float] = None,
     ) -> pd.DataFrame:
         """
@@ -1300,6 +1301,7 @@ OUTPUT:
                 The metadata properties are converted to columns in the resulting table
             experiment_id (Optional[str]): If provided, the evaluation run will be associated with this experiment.
             output_file_path (Optional[str]): The local file path to save the evaluation results. Defaults to None.
+            max_result_download_attempts (Optional[int]): Maximum number of attempts to download the evaluation results.
             timeout (Optional[float]): Timeout (seconds) for client API requests.
 
         Returns:
@@ -1335,33 +1337,56 @@ OUTPUT:
             self.logger.info(f"Evaluating dataset {dataset_id}...")
             project_id = self.project_id if self.project_id else self.project.id
 
-            evaluate_dataset_response: EvaluationEvaluateDatasetResponse = self.client.evaluation.evaluate_dataset(
-                metrics=metrics_list,
-                dataset_id=dataset_id,
-                project_id=project_id,
-                metadata=metadata or NOT_GIVEN,  # type: ignore
-                experiment_id=experiment_id or NOT_GIVEN,
-                timeout=timeout,
-            )
+            retry_delay = 0.5
 
-            if not evaluate_dataset_response.run_id:
-                raise LastmileAPIError(
-                    f"Evaluation run ID not found in response when evaluating dataset {dataset_id}. Evaluation may have failed."
+            for attempt in range(max_result_download_attempts):
+                self.logger.debug(f"Attempt {attempt + 1} of {max_result_download_attempts}...")
+                
+                evaluate_dataset_response: EvaluationEvaluateDatasetResponse = self.client.evaluation.evaluate_dataset(
+                    metrics=metrics_list,
+                    dataset_id=dataset_id,
+                    project_id=project_id,
+                    metadata=metadata or NOT_GIVEN,  # type: ignore
+                    experiment_id=experiment_id or NOT_GIVEN,
+                    timeout=timeout,
                 )
 
-            self.logger.info(
-                f"Evaluation run for dataset {dataset_id}. Downloading results from run {evaluate_dataset_response.run_id}..."
-            )
-            result_df = self.download_evaluation_run(
-                evaluate_dataset_response.run_id, output_file_path, timeout=timeout
-            )
+                if not evaluate_dataset_response.run_id:
+                    raise ValueError(
+                        f"Evaluation run ID not found in response when evaluating dataset {dataset_id}. Evaluation may have failed."
+                    )
+
+                self.logger.info(
+                    f"Evaluation run for dataset {dataset_id}. Downloading results from run {evaluate_dataset_response.run_id}..."
+                )
+
+                try:
+                    result_df = self.download_evaluation_run(
+                        evaluate_dataset_response.run_id, output_file_path, timeout=timeout
+                    )
+                    self.logger.info(f"Evaluation completed for dataset {dataset_id}.")
+                    return result_df
+                except LastmileAPIError as e:
+                    if "No columns to parse from file" in str(e) and attempt < max_result_download_attempts - 1:
+                        self.logger.warning(f"No columns found in result dataset. Attempting to retry...")
+                        try:
+                            self.client.evaluation.delete_run(id=evaluate_dataset_response.run_id, timeout=timeout)
+                            time.sleep(retry_delay)
+                            retry_delay *= 2
+                            continue
+                        except Exception as delete_err:
+                            self.logger.error(f"Failed to delete empty run {evaluate_dataset_response.run_id}: {delete_err}")
+                            raise delete_err
+                    else:
+                        raise e
+
         except Exception as e:
             self.logger.error(f"Failed to evaluate dataset: {str(e)}")
             raise LastmileAPIError(f"Failed to evaluate dataset: {str(e)}") from e
+        
+        # For typing, this should never be reached
+        raise LastmileAPIError("Failed to evaluate dataset after multiple attempts.")
 
-        self.logger.info(f"Evaluation completed for dataset {dataset_id}.")
-
-        return result_df
 
     def list_metrics(self, timeout: Optional[float] = None) -> List[Metric]:
         """
